==> samhain-1.2.2.tar.gz: samhain-1.2.2/sh_mem.h <==
/* SAMHAIN file system integrity testing                                   */
/* Copyright (C) 1999 Rainer Wichmann                                      */
/*                                                                         */
/*  This program is free software; you can redistribute it                 */
/*  and/or modify                                                          */
/*  it under the terms of the GNU General Public License as                */
/*  published by                                                           */
/*  the Free Software Foundation; either version 2 of the License, or      */
/*  (at your option) any later version.                                    */
/*                                                                         */
/*  This program is distributed in the hope that it will be useful,        */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of         */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          */
/*  GNU General Public License for more details.                           */
/*                                                                         */
/*  You should have received a copy of the GNU General Public License      */
/*  along with this program; if not, write to the Free Software            */
/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              */


#ifndef SH_MEM_H
#define SH_MEM_H


#ifdef MEM_DEBUG

void   sh_mem_openf (char * file, int fd);
void   sh_mem_closef (int fd);
void   sh_mem_check (void);
void   sh_mem_free (void * a, char * file, int line);
void * sh_mem_malloc (unsigned long size, char * file, int line);
void sh_mem_stat (void);

#define SH_FREE(a)   sh_mem_free((a), FIL__, __LINE__)
#define SH_ALLOC(a)  sh_mem_malloc((a), FIL__, __LINE__) 

#else


void   sh_mem_free (void * a);
void * sh_mem_malloc (unsigned long size);

#define SH_FREE(a)   sh_mem_free(a)
#define SH_ALLOC(a)  sh_mem_malloc(a)

#endif

/* #ifndef SH_MEM_H */
#endif

==> samhain_1.8.2.orig.tar.gz: samhain-1.8.2/sh_mem.h <==
/* SAMHAIN file system integrity testing                                   */
/* Copyright (C) 1999 Rainer Wichmann                                      */
/*                                                                         */
/*  This program is free software; you can redistribute it                 */
/*  and/or modify                                                          */
/*  it under the terms of the GNU General Public License as                */
/*  published by                                                           */
/*  the Free Software Foundation; either version 2 of the License, or      */
/*  (at your option) any later version.                                    */
/*                                                                         */
/*  This program is distributed in the hope that it will be useful,        */
/*  but WITHOUT ANY WARRANTY; without even the implied warranty of         */
/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          */
/*  GNU General Public License for more details.                           */
/*                                                                         */
/*  You should have received a copy of the GNU General Public License      */
/*  along with this program; if not, write to the Free Software            */
/*  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              */


#ifndef SH_MEM_H
#define SH_MEM_H


#ifdef MEM_DEBUG

void   sh_mem_openf (char * file, int fd);
void   sh_mem_closef (int fd);
void   sh_mem_check (void);
void   sh_mem_free (void * a, char * file, int line);
void * sh_mem_malloc (size_t size, char * file, int line);
void sh_mem_stat (void);

#define SH_FREE(a)   sh_mem_free((a), FIL__, __LINE__)
#define SH_ALLOC(a)  sh_mem_malloc((a), FIL__, __LINE__) 

#else


void   sh_mem_free (void * a);
void * sh_mem_malloc (size_t size);

#define SH_FREE(a)   sh_mem_free(a)
#define SH_ALLOC(a)  sh_mem_malloc(a)

#endif

/* #ifndef SH_MEM_H */
#endif
